/*
	equip.cc
	
	(c) Richard Thrippleton
	Licensing terms are in the 'LICENSE' file
	If that file is not included with this source then permission is not given to use this source in any way whatsoever.
*/

#include <stdio.h>
#include "database.h"
#include "error.h"

class equip //Equipment item
{
	public:
	static const short LIBSIZE=32; //Maximum equipment library size
	enum {PHASER=1,LAUNCHER=2,TRANSPORTER=3,CLOAK=4}; //Different equipment types

	static void init(); //Initialise the equipment datastructures
	static void loadlib(); //Load the equipment library
	static equip* get(short indx); //Get an equipment item by index

	short self; //Self index in the equipment cache
	char nam[65]; //Name
	short typ; //Type (see top enum);
	short mss; //Mass
	short spr; //Associated sprite index
	short col; //Colour (makes it a beam weapon)
	short snd; //Associated sound index
	short pow; //Power consumption
	short rdy; //Readiness cycle time
	short cap; //Capacity
	short rng; //Range
	short trck; //Tracking power
	short acov; //Angle coverage
	short cost; //Base cost

	private:
	equip(short self); //Constructor, give the equipment self-index value
	void load(); //Load this equipment from the database

	static equip* equips[LIBSIZE]; //Equipment database
};

void equip::init()
{
}

void equip::loadlib()
{
	char nam[16]; //Object name to load equipment data from

	for(short i=0;i<LIBSIZE;i++)
	{
		sprintf(nam,"Equipment%hd",i);
		try
		{
			database::switchobj(nam);
			equips[i]=new equip(i);
			equips[i]->load();
		}
		catch(error it)
		{
		}
	}
}

equip* equip::get(short indx)
{
	if(indx>=0 && indx<LIBSIZE)
	{
		if(equips[indx])
			return equips[indx];
		else
			return NULL;
	}
	else
		return NULL;
}

equip::equip(short self)
{
	this->self=self;
}

void equip::load()
{
	database::getvalue("Name",nam);
	typ=database::getvalue("Type");
	mss=database::getvalue("Mass");
	spr=database::getvalue("Sprite");
	col=database::getvalue("Colour");
	snd=database::getvalue("Sound");
	pow=database::getvalue("Power");
	rdy=database::getvalue("CycleTime");
	cap=database::getvalue("Capacity");
	rng=database::getvalue("Range");
	trck=database::getvalue("Tracking");
	acov=database::getvalue("Coverage");
	cost=database::getvalue("Cost");
}

equip* equip::equips[LIBSIZE];
