/*
	graphic.h
	
	(c) Richard Thrippleton
	Licensing terms are in the 'LICENSE' file
	If that file is not included with this source then permission is not given to use this source in any way whatsoever.
*/

struct sbox //Bounding box on screen
{
	short x,y,w,h; //Co-ordinates, width and height
};

class graphic //A sprite object
{
	public:
	static const short ISIZE=512; //Graphics index size
	enum {LOGO=0,FIRE=1,NAV=2,WARP=3,PANEL=4,GRID=5,POS=6,TRG=7}; //Special gfx index/file numbers
	enum {BLACK=0,RED=1,LIGHTRED=2,GREEN=3,LIGHTGREEN=4,BLUE=5,LIGHTBLUE=6,YELLOW=7,ORANGE=8,PURPLE=9,GREY=10,DARKGREY=11,WHITE=12}; //Colour values

	static void init(); //Initialise the graphic system data
	static void setup(bool big,bool full); //Setup the screen, with big as true sets up an extra large window, full for fullscreen
	static void blit(); //Commit all graphics to the screen
	static graphic* get(short indx); //Fetch a graphic sprite by index
	static void string(char* str,short x,short y); //Render a string to the screen, string and co-ordinates given
	static void box(sbox* box,short col); //Render a box of given dimensions and color to the screen
	static void clip(sbox* box); //Set the graphics clipping box
	static void pix(short x,short y,short col); //Render a pixel to the screen
	static sbox dimension(); //Return the dimensions of the screen as an sbox
	static void line(short x1,short x2,short y1,short y2,short col); //Draw a line with given colour and co-ordinates

	void draw(short x,short y,short rot,short zout,short haze,bool trg); //Draw this graphic at given co-ordinates, rotation and zoom-out, with given haze percentage. trg determines if targetting crosshairs are drawn

	static unsigned long cols[16]; //Colour keys, defined at initialisation
};
