/*
	sockhelper.cc
	
	(c) Richard Thrippleton
	Licensing terms are in the 'LICENSE' file
	If that file is not included with this source then permission is not given to use this source in any way whatsoever.
*/

#include <string.h>
#include "constants.h"
#include "error.h"
#include "sockhelper.h"

sockhelper::sockhelper(TCPsocket sock)
{
	this->sock=sock;
	poll=SDLNet_AllocSocketSet(1);
	if(!poll)
		throw error("Error creating a socket set");
	SDLNet_TCP_AddSocket(poll,sock);
	ins=0;
	outs=0;	
	take=0;
	cnt=0;
}

sockhelper::~sockhelper()
{
	SDLNet_FreeSocketSet(poll);
}

void sockhelper::pump()
{
	short r; //Data received value

	if(outs>0)
	{
		if(SDLNet_TCP_Send(sock,out,outs)<outs)
			throw error("Other end dropped connection (TCP_Send)");
		cnt+=outs;
		outs=0;
	}
	SDLNet_CheckSockets(poll,0);
	if(SDLNet_SocketReady(sock) && ins<1024)
	{
		r=SDLNet_TCP_Recv(sock,in+ins,1024-ins);
		if(r<=0)
			throw error("Other end dropped connection (TCP_Recv)");
		cnt+=r;
		ins+=r;
	}
}

void sockhelper::send(unsigned char* data,short len)
{
	if(outs+len>=1024)
		pump();
	for(short i=0;i<len && outs<1024;i++)
	{
		out[outs]=data[i];
		outs++;
	}
}

unsigned char* sockhelper::request(short len)
{
	if(len>ins)
		return NULL;
	else
	{
		take=len;
		return in;
	}
}

void sockhelper::suck()
{
	if(take>0)
	{
		for(short i=take;i<ins;i++)
			in[i-take]=in[i];
		ins-=take;
			take=0;
	}
}

long sockhelper::getcount()
{
	long out; //Value to return

	out=cnt;
	cnt=0;
	return out;
}
