/*
	ticker.cc
	
	(c) Richard Thrippleton
	Licensing terms are in the 'LICENSE' file
	If that file is not included with this source then permission is not given to use this source in any way whatsoever.
*/

#include <SDL.h>
#include "error.h"

class ticker //FPS regulator
{
	public:
	ticker(short fps); //Constructor, give desired fps value

	void start(); //Start the timer
	void tick(); //Mark next tick and block for appropriate time

	double afps; //Actual fps

	private:
	long stm,otm,ntm; //Start 500 tick segment, before, and after times
	long pas; //Precalculated delay required
	long tcks; //Ticks so far
};

ticker::ticker(short fps)
{
	tcks=0;
	pas=1+1000/fps;
	afps=fps;
}

void ticker::start()
{
	otm=SDL_GetTicks();
	stm=SDL_GetTicks();
}

void ticker::tick()
{
	long dly; //Delay to apply

	ntm=SDL_GetTicks();
	dly=pas-(ntm-otm);
	otm=ntm;
	otm+=dly;
	if(dly>0)
		SDL_Delay(dly);
	if(tcks%10==0)
	{
		if((ntm-stm)!=0)
			afps=(double)(10*1000)/(double)(ntm-stm);
		stm=ntm;
	}
	tcks++;
}
